#
# spec file for package ghc-ansi-terminal
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name ansi-terminal
Name:           ghc-%{pkg_name}
Version:        0.9
Release:        lp151.1.2
Summary:        Simple ANSI terminal support, with Windows compatibility
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-colour-devel
BuildRequires:  ghc-rpm-macros

%description
ANSI terminal support for Haskell: allows cursor movement, screen clearing,
color output, showing or hiding the cursor, and changing the title.
Works on UNIX and Windows.

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%changelog
* Sun Jan 27 2019 psimons@suse.com
- Update ansi-terminal to version 0.9.
  Version 0.9
  - ----------
  * Add support for 256-color palettes with new `SetPaletteColor` constructor of
    `SGR` type, and `xterm6LevelRGB`, `xterm24LevelGray` and `xtermSystem`.
  * Remove deprecated `getCursorPosition`. (Use `getCursorPosition0` instead.)
  * Add `hSupportsANSIColor`.
  * Add `getTerminalSize`.
  * Improvements to Haddock documentation.
* Mon Oct 29 2018 psimons@suse.com
- Update ansi-terminal to version 0.8.2.
  Version 0.8.2
  - ------------
  * Add `getCursorPosition0` and deprecate `getCursorPosition`. Any position
    provided by the latter is 1-based. Any position provided by the former is
    0-based, consistent with `setCursorColumn` and `setCursorPosition`.
  * Improvements to Haddock documentation in respect of 0-based and 1-based
    cursor positions.
* Thu Oct  4 2018 psimons@suse.com
- Update ansi-terminal to version 0.8.1.
  * Add `hSupportsANSIWithoutEmulation`. On Windows 10, if the handle is identifed
    as connected to a native terminal ('Command Prompt' or 'PowerShell'), the
    processing of 'ANSI' control characters will be enabled.
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Mon May 14 2018 psimons@suse.com
- Update ansi-terminal to version 0.8.0.4.
  * On Windows, `hSupportsANSI` now recognises if the handle is connected to a
    'mintty' terminal.
  * On Windows, try to enable ANSI on ConHost terminals even if a TERM environment
    variable exits (such as with the Hyper 2 terminal)
  * Minor improvements to Haddock documentation
  * Improve README and Haddock documentation
  * On Windows, fix compatability with earlier GHC versions
  * Drop support for GHC versions before 6.12.1 (released December 2009)
  * On Windows, if the standard output channel is valid but not a ConHost
    terminal, assume it is ANSI-enabled rather than failing
  * On Windows, output the improved error message to the standard error channel
    rather than the standard output channel
  * Make the fields of `SGR` strict
  * Make compatible with GHC 8.2.2
  * Improve the error message on Windows when not ANSI-capable or ConHost
  * Recognise Appveyor build environment as ANSI-enabled
    `getReportedCursorPosition`: don't let the cursor reporting code be echo'd
  * Allow saving, restoring, and querying the current cursor position
  * Fix a couple of issues with the Reset emulation on Windows
  * Add 24-bit RGB color support
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Thu Jun  8 2017 psimons@suse.com
- Update to version 0.6.3.1.
* Wed May 31 2017 psimons@suse.com
- Update to version 0.6.3.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.6.2.3 revision 0 with cabal2obs.
* Sun Sep 13 2015 mimi.vx@gmail.com
- update to 0.6.2.3
  * Add an example to the haddocks
* Sun Aug 23 2015 mimi.vx@gmail.com
- update to 0.6.2.2
  * Fix a GHC 7.10 warning
* Thu May 14 2015 mimi.vx@gmail.com
- regenerated spec with  cabal-rpm
* Sat Nov 22 2014 mimi.vx@gmail.com
- add group to devele section
* Sun Nov 16 2014 mimi.vx@gmail.com
- initial commit
